@@ -12,18 +12,30 @@ function paraselene_get_id(id){
 function ParaseleneWindowSize(){
 	this.top=window.pageYOffset;
 	if(!this.top)	this.top=document.documentElement.scrollTop;
-	this.hight=window.innerHight;
-	if(!this.hight)	this.hight=document.body.clientHight;
+	this.height=window.innerHeight;
+	if(!this.height)	this.height=document.documentElement.clientHeight;
+	if(!this.height)	this.height=document.body.clientHeight;
 	this.left=window.pageXOffset;
 	if(!this.left)	this.left=document.documentElement.scrollLeft;
 	this.width=window.innerWidth;
+	if(!this.width)	this.width=document.documentElement.clientWidth;
 	if(!this.width)	this.width=document.body.clientWidth;
 }
 
+function ParaseleneDocumentSize(){
+	var size=new ParaseleneWindowSize();
+	this.height=document.documentElement.scrollHeight;
+	if(!this.height)	this.height=document.body.scrollHeight;
+	if(this.height<size.height)	this.height=size.height;
+	this.width=document.documentElement.scrollWidth;
+	if(!this.width)	this.width=document.body.scrollWidth;
+	if(this.width<size.width)	this.height=size.width;
+}
+
 function ParaseleneTagSize(tag){
 	var rect=tag.getBoundingClientRect();
 	this.width=rect.right-rect.left+1;
-	this.hight=rect.bottom-rect.top+1;
+	this.height=rect.bottom-rect.top+1;
 }
 
 function ParaseleneTagXY(tag){
@@ -45,8 +57,8 @@ function paraselene_tag_position(tag,x,y){
 		x=x-sub;
 	}
 	if(x<0)	x=0;
-	if((y+size.hight)>win.hight){
-		sub=y+size.hight-win.hight;
+	if((y+size.height)>win.height){
+		sub=y+size.height-win.height;
 		y=y-sub;
 	}
 	if(y<0)	y=0;
@@ -56,7 +68,7 @@ function paraselene_tag_position(tag,x,y){
 
 function paraselene_tag_center(tag,x,y){
 	var size=new ParaseleneTagSize(tag);
-	paraselene_tag_position(tag,x-size.width/2,y-size.hight/2);
+	paraselene_tag_position(tag,x-size.width/2,y-size.height/2);
 }
 
 function paraselene_tag_move(tag,x,y){
@@ -69,6 +81,9 @@ var paraselene_move_obj;
 var paraselene_move_x;
 var paraselene_move_y;
 
+var paraselene_mous_up_x=0;
+var paraselene_mous_up_y=0;
+
 function paraselene_get_event(ev){
 	if(ev)	return ev;
 	return window.event;
@@ -85,6 +100,9 @@ function paraselene_tag_set_event(dialog,tag){
 		return false;
 	};
 	document.onmouseup=function(kmouse){
+		kmouse=paraselene_get_event(kmouse);
+		paraselene_mous_up_x=kmouse.clientX;
+		paraselene_mous_up_y=kmouse.clientY;
 		if(!paraselene_move_obj)	return true;
 		paraselene_move_obj=undefined;
 		return false;
@@ -92,6 +110,12 @@ function paraselene_tag_set_event(dialog,tag){
 	document.onmousemove=function(kmouse){
 		if(!paraselene_move_obj)return true;
 		kmouse=paraselene_get_event(kmouse);
+		if(navigator.userAgent.indexOf("MSIE")!=-1){
+			if(kmouse.button==0){
+				paraselene_move_obj=undefined;
+				return true;
+			}
+		}
 		paraselene_tag_move(paraselene_move_obj,kmouse.clientX-paraselene_move_x,kmouse.clientY-paraselene_move_y);
 		paraselene_move_x=kmouse.clientX;
 		paraselene_move_y=kmouse.clientY;
@@ -195,7 +219,7 @@ function paraselene_back_kill_stop(){
 }
 
 function paraselene_comet_callback(obj){
-	paraselene_action(document.body,obj);
+	paraselene_action(obj);
 }
 
 function paraselene_comet_start(){
@@ -250,7 +274,23 @@ function paraselene_z_order(pop,del_f){
 
 var paraselene_modal_count=0;
 
-function paraselene_dialog_open(dialog,tag){
+function paraselene_back_resize(){
+	if(paraselene_modal_count=0)	return;
+	var size=new ParaseleneDocumentSize();
+	var x=size.width;
+	var y=size.height;
+	for (var i=0;i<paraselene_popup.length;i++){
+		size=new ParaseleneTagSize(paraselene_popup[i]);
+		if(x<size.width)	x=size.width;
+		if(y<size.height)	y=size.height;
+	}
+	var back=paraselene_get_id("paraseleneEclipse");
+	back.style.height=y+"px";
+	back.style.width=x+"px";
+	setTimeout(paraselene_back_resize,500);
+}
+
+function paraselene_dialog_open(dialog){
 	var point=paraselene_get_id("paraseleneDragonsHead");
 	if(!point)	return;
 	if(dialog.active){
@@ -266,11 +306,13 @@ function paraselene_dialog_open(dialog,tag){
 		if(paraselene_modal_count<1){
 			back.style.zIndex=z;
 			back.style.display="block";
+			paraselene_modal_count++;
+			paraselene_back_resize();
 		}
 		else{
 			back.style.zIndex++;
+			paraselene_modal_count++;
 		}
-		paraselene_modal_count++;
 	}
 	var base=document.createElement("div");
 	base.id=pageid;
@@ -294,14 +336,14 @@ function paraselene_dialog_open(dialog,tag){
 	base.appendChild(head);
 	base.appendChild(body);
 	paraselene_popup.push(base);
-	var xy=new ParaseleneTagXY(tag);
-	paraselene_tag_center(base,xy.x,xy.y);
 	point.appendChild(base);
+	paraselene_tag_center(base,paraselene_mous_up_x,paraselene_mous_up_y);
 	paraselene_back_kill_start(pageid);
 	paraselene_tag_set_event(base,head);
 }
 
-function paraselene_action(tag,obj){
+function paraselene_action(obj){
+	var resize_f=false;
 	for(var i=0;i<obj.data.length;i++){
 		var val=obj.data[i];
 		if(val.location){
@@ -309,7 +351,8 @@ function paraselene_action(tag,obj){
 			continue;
 		}
 		if(val.open){
-			paraselene_dialog_open(val.open,tag);
+			paraselene_dialog_open(val.open);
+			resize_f=true;
 			continue;
 		}
 		if(val.close){
@@ -328,11 +371,13 @@ function paraselene_action(tag,obj){
 					back.style.zIndex--;
 				}
 			}
+			resize_f=true;
 			continue;
 		}
 		var update_tag=val.tag;
 		var target=paraselene_get_id(update_tag.id);
 		if(target)	target.innerHTML=update_tag.body;
+		resize_f=true;
 	}
 }
 
@@ -369,7 +414,7 @@ function paraselene_get(o,url,key){
 		paraselene_error_page(svr);
 	}
 	else{
-		paraselene_action(o,eval('('+svr.responseText+')'));
+		paraselene_action(eval('('+svr.responseText+')'));
 	}
 	document.body.style.cursor="auto";
 	return true;
@@ -406,7 +451,7 @@ function paraselene_form_ok(key){
 		paraselene_error_page(svr);
 	}
 	else{
-		paraselene_action(paraselene_called_form,eval('('+svr.responseText+')'));
+		paraselene_action(eval('('+svr.responseText+')'));
 	}
 	document.body.style.cursor="auto";
 	paraselene_called_form=undefined;
