@@ -107,6 +107,13 @@ public abstract class Json extends #1.SuperPage implements Downloadable {
 			"text/html; charset=utf-8":
 			"text/javascript+json; charset=utf-8";
 	}
+
+	/**
+	 * キャッシュ禁止指定。
+	 * @return false:ブラウザキャッシュを許可します。
+	 */
+	public boolean isNoCache() { return true; }
+
 	/**
 	 * 出力内容の取得。
 	 * @return ストリーム。
