@@ -1148,5 +1148,14 @@ public abstract class Page implements Serializable {
 	public CSSValuable[] getPopupBackGround() {
 		return new CSSValuable[] { new Color( WebColor.LAVENDER ) };
 	}
+
+	/**
+	 * キャッシュ禁止指定。常に false を返します。
+	 * ただし、getLastModified に null 以外を返すと、この戻り値は無視されます。
+	 * 必要に応じてオーバーライドして下さい。
+	 * @return true:ブラウザキャッシュを禁止します、
+	 * false:ブラウザキャッシュを許可します。
+	 */
+	public boolean isNoCache() { return false; }
 }
 
