@@ -290,6 +290,14 @@ public class TagMap {
 		},
 
 	// 通常
+		{ "a", "Anchor",
+			"new Anchor()",
+			new DynaTag() {
+				Tag getTag( String name, ArrayList<Attribute> attr ) {
+					return setAttr( new Anchor(), attr );
+				}
+			}
+		},
 		{ "form", "Form",
 			"new Form()",
 			new DynaTag() {
