@@ -239,6 +239,10 @@ public class Option implements Serializable {
 	private static volatile BufferedWriter	trace_writer = null;
 	private static Thread flusher = null;
 
+	static boolean isSpy() {
+		return trace_writer != null;
+	}
+
 	private static void traceClose() {
 		try {
 			synchronized( MY_CLASS ) {
@@ -292,7 +296,7 @@ public class Option implements Serializable {
 		flusher.start();
 	}
 
-	private static void trace( String mes ) {
+	private static void trace( String mes, boolean st_f ) {
 		try {
 			synchronized( MY_CLASS ) {
 				if ( trace_writer == null )	return;
@@ -306,7 +310,17 @@ public class Option implements Serializable {
 					trace_writer.write( CR );
 					trace_writer.write( mes );
 					trace_writer.write( CR );
-					return;
+					break;
+				}
+				if ( st_f ) {
+					int	start = 1;
+					for ( ; start < sta.length; start++ ) {
+						if ( !sta[start].getClassName().equals( MY_CLASS ) ) break;
+					}
+					for ( ; start < sta.length; start++ ) {
+						trace_writer.write( sta[start].toString() );
+						trace_writer.write( CR );
+					}
 				}
 			}
 		}
@@ -319,12 +333,17 @@ public class Option implements Serializable {
 		for ( int i = 0; i < s.length; i++ ) {
 			buf = buf.append( s[i] );
 		}
-		trace( buf.toString() );
+		trace( buf.toString(), false );
 	}
 
 	static void trace( String format, Object ... o ) {
 		if ( trace_writer == null )	return;
-		trace( String.format( format, o ) );
+		trace( String.format( format, o ), false );
+	}
+
+	static void traceWithStack( String format, Object ... o ) {
+		if ( trace_writer == null )	return;
+		trace( String.format( format, o ), true );
 	}
 }
 
