@@ -76,8 +76,14 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 			data = pending.get( id );
 		}
 		id.getPageFactory().returnPage( out );
-		if ( data == null )	return false;
-		if ( holder.request.getURI().toString().indexOf( data.uri ) < 0 )	return false;
+		if ( data == null ) {
+			Option.trace( "redirect pending data null" );
+			return false;
+		}
+		if ( holder.request.getURI().toString().indexOf( data.uri ) < 0 ) {
+			Option.trace( "redirect path unmatched pending(%s) call(%s)", data.uri, holder.request.getURI().toString() );
+			return false;
+		}
 		sv.write( data.out_page, false, data.fw, holder );
 		return true;
 	}
