@@ -170,6 +170,7 @@ public abstract class Supervisor extends HttpServlet {
 		String[]	part = uri.split( "/" );
 		boolean	flag = false;
 		String	head = null;
+		boolean	alias_f = false;
 		for ( int i = 0; i < part.length; i++ ) {
 			int	def_no;
 			for ( def_no = 0; def_no < LINK_DEF.length; def_no++ ) {
@@ -200,7 +201,7 @@ public abstract class Supervisor extends HttpServlet {
 			uri = holder.response.encodeURL( URIValue.encode( uri, enc ) );
 		}
 		else {
-			boolean	alias_f = holder.sv.getPageFactory().isAlias( uri );
+			alias_f = holder.sv.getPageFactory().isAlias( uri );
 			if ( alias_f && to_key != HistorySet.ROOT ) {
 				StringBuilder	buf = new StringBuilder( TransactionSequencer.SELENE[5] );
 				buf = buf.append( "." );
@@ -288,9 +289,13 @@ public abstract class Supervisor extends HttpServlet {
 	}
 
 	private static void clear_session( HttpSession s ) {
-//Thread.dumpStack();
 		s.invalidate();
-		Option.trace( "session cleared" );
+		Option.traceWithStack( "session cleared" );
+/*
+		if ( Option.isSpy() ) {
+			Thread.dumpStack();
+		}
+*/
 	}
 
 	/**
@@ -650,8 +655,9 @@ public abstract class Supervisor extends HttpServlet {
 				res.addHeader( "Last-Modified", date.toString() );
 				res.addHeader( "Cache-Control", "public" );
 			}
-			else {
-				//res.addHeader( "Cache-Control", "no-cache, no-store" );
+			else if ( next_page.isNoCache() ) {
+				res.addHeader( "Pragma", "no-cache" );
+				res.addHeader( "Cache-Control", "no-cache, no-store" );
 			}
 			if ( fw != null ) {
 				int	ck_cnt = fw.out_cookie.size();
