@@ -34,13 +34,19 @@ class Null extends NullPage {
  */
 public class TransactionSequencer implements Serializable {
 	private static final long serialVersionUID = 2L;
-	private static final String[] SALANE = new String[] {
-		"lu", "mo", "on", "na", "art", "mis"
+	static final String[] SELENE = new String[] {
+		"lu",	// 0: リクエストID
+		"mo",	// 1: 遷移元ページ
+		"on",	// 2: 遷移先ページ
+		"na",	// 3: 固定拡張子
+		"art",	// 4: 遷移元履歴キー
+		"mis",	// 5: 遷移先履歴キー
+		"dia",	// 6: alias
 	};
 	/**
 	 * Paraselene拡張子。
 	 */
-	public static final String EXTENSION = "." + SALANE[3];
+	public static final String EXTENSION = "." + SELENE[3];
 	private volatile int seq = 0;
 	private HashMap<Integer,Boolean>	no_map = new HashMap<Integer,Boolean>();
 	private static final String[] HEAD = { "seleno", "lilith" };
@@ -73,50 +79,50 @@ public class TransactionSequencer implements Serializable {
 	public static String makeURI( TransactionSequencer seq, PageID from, PageID to, int from_key, int to_key, boolean flag ) {
 		StringBuilder	buf = new StringBuilder();
 		if ( flag && seq != null ) {
-			buf = buf.append( SALANE[0] );
+			buf = buf.append( SELENE[0] );
 			buf = buf.append( "." );
 			buf = buf.append( HEAD[0] );
 			buf = buf.append( Integer.toString( seq.newNo( to ), Character.MAX_RADIX ) );
 			buf = buf.append( "." );
 		}
 		if ( from != null ) {
-			buf = buf.append( SALANE[1] );
+			buf = buf.append( SELENE[1] );
 			buf = buf.append( "." );
 			buf = buf.append( Integer.toString( from.getID(), Character.MAX_RADIX ) );
 			buf = buf.append( "." );
 			if ( flag && from_key != HistorySet.ROOT ) {
-				buf = buf.append( SALANE[4] );
+				buf = buf.append( SELENE[4] );
 				buf = buf.append( "." );
 				buf = buf.append( Integer.toString( from_key, Character.MAX_RADIX ) );
 				buf = buf.append( "." );
 			}
 		}
 		if ( flag && to_key != HistorySet.ROOT ) {
-			buf = buf.append( SALANE[5] );
+			buf = buf.append( SELENE[5] );
 			buf = buf.append( "." );
 			buf = buf.append( Integer.toString( to_key, Character.MAX_RADIX ) );
 			buf = buf.append( "." );
 		}
-		buf = buf.append( SALANE[2] );
+		buf = buf.append( SELENE[2] );
 		buf = buf.append( "." );
 		buf = buf.append( Integer.toString( to.getID(), Character.MAX_RADIX ) );
 		buf = buf.append( "." );
-		buf = buf.append( SALANE[3] );
+		buf = buf.append( SELENE[3] );
 		return buf.toString();
 	}
 
 	static String makeRedirectURI( TransactionSequencer seq, PageID to ) {
 		StringBuilder	buf = new StringBuilder();
-		buf = buf.append( SALANE[0] );
+		buf = buf.append( SELENE[0] );
 		buf = buf.append( "." );
 		buf = buf.append( HEAD[1] );
 		buf = buf.append( Integer.toString( seq.newNo( null ), Character.MAX_RADIX ) );
 		buf = buf.append( "." );
-		buf = buf.append( SALANE[2] );
+		buf = buf.append( SELENE[2] );
 		buf = buf.append( "." );
 		buf = buf.append( Integer.toString( to.getID(), Character.MAX_RADIX ) );
 		buf = buf.append( "." );
-		buf = buf.append( SALANE[3] );
+		buf = buf.append( SELENE[3] );
 		return buf.toString();
 	}
 
@@ -137,13 +143,13 @@ public class TransactionSequencer implements Serializable {
 		for ( int i = path.length - 1; i >= 0; i-- ) {
 			String[]	body = path[i].split( "\\." );
 			if ( body.length == 0 )	continue;
-			if ( !SALANE[3].equals( body[body.length - 1] ) )	continue;
+			if ( !SELENE[3].equals( body[body.length - 1] ) )	continue;
 			PathData	ret = new PathData();
 			int	cnt = body.length - 1;
 			boolean	redirect_f = false;
 			boolean	request_id = false;
 			for ( int j = 0; j < cnt; j += 2 ) {
-				if ( seq != null && SALANE[0].equals( body[j] ) ) {
+				if ( seq != null && SELENE[0].equals( body[j] ) ) {
 					if ( body[j + 1].length() <= HEAD_LENGTH )	return null;
 					String	head = body[j + 1].substring( 0, HEAD_LENGTH );
 					String	number = body[j + 1].substring( HEAD_LENGTH );
@@ -160,10 +166,10 @@ public class TransactionSequencer implements Serializable {
 						seq.no_map.put( no, true );
 					}
 				}
-				else if ( SALANE[1].equals( body[j] ) ) {
+				else if ( SELENE[1].equals( body[j] ) ) {
 					ret.from = getPage( body[j + 1], fact );
 				}
-				else if ( SALANE[2].equals( body[j] ) ) {
+				else if ( SELENE[2].equals( body[j] ) ) {
 					if ( redirect_f ) {
 						ret.redirect = getPage( body[j + 1], fact );
 					}
@@ -171,10 +177,10 @@ public class TransactionSequencer implements Serializable {
 						ret.to = getPage( body[j + 1], fact );
 					}
 				}
-				else if ( SALANE[4].equals( body[j] ) ) {
+				else if ( SELENE[4].equals( body[j] ) ) {
 					ret.from_histry = Integer.parseInt( body[j + 1], Character.MAX_RADIX );
 				}
-				else if ( SALANE[5].equals( body[j] ) ) {
+				else if ( SELENE[5].equals( body[j] ) ) {
 					ret.to_histry = Integer.parseInt( body[j + 1], Character.MAX_RADIX );
 					if ( hset != null && ret.to_histry == HistorySet.RAND ) {
 						ret.to_histry = hset.toInt();
@@ -200,11 +206,11 @@ public class TransactionSequencer implements Serializable {
 		for ( int i = path.length -1; i >= 0; i-- ) {
 			String[]	body = path[i].split( "\\." );
 			if ( body.length == 0 )	continue;
-			if ( !SALANE[3].equals( body[body.length - 1] ) )	continue;
+			if ( !SELENE[3].equals( body[body.length - 1] ) )	continue;
 			int	cnt = body.length - 1;
 			for ( int j = 0; j < cnt; j += 2 ) {
-				if ( SALANE[0].equals( body[j] ) )	return true;
-				if ( SALANE[1].equals( body[j] ) )	return true;
+				if ( SELENE[0].equals( body[j] ) )	return true;
+				if ( SELENE[1].equals( body[j] ) )	return true;
 			}
 			return false;
 		}
